.. include:: README.rst

Complete API and advanced usage
-------------------------------

.. toctree::
    :maxdepth: 2

    execution-model.rst
    using-task-class.rst
    tips-and-tricks.rst
    api/collective.celery.rst

Changelog
---------

.. toctree::
    :maxdepth: 2

    CHANGES.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
